@@ -46,7 +46,10 @@ class GutterModule(nexus.NexusModule):
         return 'Gutter'
 
     def get_urls(self):
-        from django.conf.urls.defaults import patterns, url
+        try:
+            from django.conf.urls import patterns, url
+        except ImportError:
+            from django.conf.urls.defaults import patterns, url
 
         urlpatterns = patterns(
             '',
